@@ -124,6 +124,13 @@ class WebHook(MailchimpBaseView):
                  'old_email': data['data[old_email]'],
                  'new_email': data['data[new_email]'],
             })
+        elif data['type'] == 'campaign':
+            kwargs.update({
+                'campaign_id': data['data[id]'],
+                'subject': data['data[subject]'],
+                'status': data['data[status]'],
+                'reason': data['data[reason]'],
+            })
         else:
             merge_re = re.compile('data\[merges\]\[(?P<name>w+)\]')
             merges = {}
@@ -136,11 +143,12 @@ class WebHook(MailchimpBaseView):
                     merges[name] = value
             kwargs.update({
                 'email': data['data[email]'],
-                'interests': [i.strip() for i in data['data[merges][INTERESTS]'].split(',')],
                 'fname': data['data[merges][FNAME]'],
                 'lname': data['data[merges][LNAME]'],
                 'merges': merges,
             })
+            if 'data[merges][INTERESTS]' in data:
+                kwargs['interests'] = [i.strip() for i in data['data[merges][INTERESTS]'].split(',')]
         signal.send(sender=self.connection, **kwargs)
         return self.response("ok")
 
